<?php
/*
NOTICE OF LICENSE

This source file is subject to the NekloEULA that is bundled with this package in the file ICENSE.txt.

It is also available through the world-wide-web at this URL: http://store.neklo.com/LICENSE.txt

Copyright (c)  Neklo (http://store.neklo.com/)
*/


namespace Neklo\Scheduler\Helper;

use Magento\Framework\App\Helper\AbstractHelper;

class Sender extends AbstractHelper
{
    /**
     * @var \Magento\Framework\Mail\Template\TransportBuilder
     */
    private $transportBuilder;

    /**
     * @var \Magento\Framework\Translate\Inline\StateInterface
     */
    private $state;

    /**
     * @var Config
     */
    private $configHelper;

    /**
     * Sender constructor.
     * @param \Magento\Framework\App\Helper\Context $context
     * @param \Magento\Framework\Mail\Template\TransportBuilder $transportBuilder
     * @param \Magento\Framework\Translate\Inline\StateInterface $state
     * @param Config $configHelper
     */
    public function __construct(
        \Magento\Framework\App\Helper\Context $context,
        \Magento\Framework\Mail\Template\TransportBuilder $transportBuilder,
        \Magento\Framework\Translate\Inline\StateInterface $state,
        \Neklo\Scheduler\Helper\Config $configHelper
    ) {
        $this->transportBuilder = $transportBuilder;
        $this->state = $state;
        $this->configHelper = $configHelper;

        parent::__construct($context);
    }

    public function sendError($jobName, $errorMessage = '')
    {
        $template = $this->configHelper->getEmailTemplate();

        $templateOptions = [
            'area' => \Magento\Framework\App\Area::AREA_ADMINHTML,
            'store' => 0
        ];

        $templateVars = [
            'job_name'   => $jobName,
            'message'    => $errorMessage,
        ];

        $sender = $this->configHelper->getEmailSender();

        $toEmail = $this->configHelper->getEmailRecipient();

        if ($toEmail === null || !$toEmail || $toEmail == '') {
            return;
        }

        $this->state->suspend();
        $transport = $this->transportBuilder->setTemplateIdentifier($template)
            ->setTemplateOptions($templateOptions)
            ->setTemplateVars($templateVars)
            ->setFrom($sender)
            ->addTo($toEmail)
            ->getTransport();
        $transport->sendMessage();
        $this->state->resume();
    }
}
