<?php
/*
NOTICE OF LICENSE

This source file is subject to the NekloEULA that is bundled with this package in the file ICENSE.txt.

It is also available through the world-wide-web at this URL: http://store.neklo.com/LICENSE.txt

Copyright (c)  Neklo (http://store.neklo.com/)
*/


namespace Neklo\Scheduler\Ui\Component\Listing\Columns\Job;

use Magento\Framework\View\Element\UiComponent\ContextInterface;
use Magento\Framework\View\Element\UiComponentFactory;
use Magento\Ui\Component\Listing\Columns\Column;
use Magento\Framework\UrlInterface;

class Actions extends Column
{
    /* Url path */
    const URL_PATH_EDIT = 'neklo_scheduler/job/edit';
    const URL_PATH_DELETE = 'neklo_scheduler/job/delete';
    const URL_PATH_EXECUTE = 'neklo_scheduler/job/execute';
    const URL_PATH_SCHEDULE = 'neklo_scheduler/job/schedule';

    /**
     * @var UrlInterface
     */
    private $urlBuilder;

    /**
     * @var string
     */
    private $editUrl;

    /**
     * @param ContextInterface               $context
     * @param UiComponentFactory             $uiComponentFactory
     * @param UrlInterface                   $urlBuilder
     * @param \Neklo\Scheduler\Helper\Config $config
     * @param array                          $components
     * @param array                          $data
     */
    public function __construct(
        ContextInterface $context,
        UiComponentFactory $uiComponentFactory,
        UrlInterface $urlBuilder,
        array $components = [],
        array $data = []
    ) {
        $this->urlBuilder = $urlBuilder;
        $this->editUrl = self::URL_PATH_EDIT;
        parent::__construct($context, $uiComponentFactory, $components, $data);
    }

    /**
     * Prepare Data Source
     *
     * @param  array $dataSource
     *
     * @return array
     */
    public function prepareDataSource(array $dataSource)
    {
        if (isset($dataSource['data']['items'])) {
            foreach ($dataSource['data']['items'] as & $item) {
                $name = $this->getData('name');
                if (isset($item['id'])) {
                    $item[$name]['edit'] = [
                        'href'  => $this->urlBuilder->getUrl($this->editUrl, ['id' => $item['id']]),
                        'label' => __('Edit')
                    ];
                    $item[$name]['execute'] = [
                        'href'    => $this->urlBuilder->getUrl(self::URL_PATH_EXECUTE, ['id' => $item['id']]),
                        'label'   => __('Run Job'),
                        'confirm' => [
                            'title'   => __('Run "${ $.$data.name }"'),
                            'message' => __('Are you sure you want to run "${ $.$data.name }" job?')
                        ]
                    ];
                    $item[$name]['schedule'] = [
                        'href'    => $this->urlBuilder->getUrl(self::URL_PATH_SCHEDULE, ['id' => $item['id']]),
                        'label'   => __('Schedule Job'),
                        'confirm' => [
                            'title'   => __('Schedule "${ $.$data.name }"'),
                            'message' => __('Are you sure you want to schedule "${ $.$data.name }" job?')
                        ]
                    ];
                }
            }
        }

        return $dataSource;
    }
}
